Index: /trunk/src/VBox/Frontends/VirtualBox/src/widgets/UIMenuBarEditorWindow.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/widgets/UIMenuBarEditorWindow.cpp	(revision 75357)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/widgets/UIMenuBarEditorWindow.cpp	(revision 75358)
@@ -1313,7 +1313,10 @@
                            UIExtraDataMetaDefs::RuntimeMenuViewActionType_Resize,
                            gpConverter->toInternalString(UIExtraDataMetaDefs::RuntimeMenuViewActionType_Resize));
-        prepareNamedAction(pMenu, tr("Virtual Screen Mapping"),
-                           UIExtraDataMetaDefs::RuntimeMenuViewActionType_Multiscreen,
-                           gpConverter->toInternalString(UIExtraDataMetaDefs::RuntimeMenuViewActionType_Multiscreen));
+        prepareNamedAction(pMenu, tr("Virtual Screen Remap"),
+                           UIExtraDataMetaDefs::RuntimeMenuViewActionType_Remap,
+                           gpConverter->toInternalString(UIExtraDataMetaDefs::RuntimeMenuViewActionType_Remap));
+        prepareNamedAction(pMenu, tr("Virtual Screen Rescale"),
+                           UIExtraDataMetaDefs::RuntimeMenuViewActionType_Rescale,
+                           gpConverter->toInternalString(UIExtraDataMetaDefs::RuntimeMenuViewActionType_Rescale));
     }
 }

Index: /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIActionPoolRuntime.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIActionPoolRuntime.cpp	(revision 75357)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/globals/UIActionPoolRuntime.cpp	(revision 75358)
@@ -3230,8 +3230,8 @@
     AssertPtrReturnVoid(pMenu);
 
     /* Do we have to show resize, multiscreen or scale factor actions? */
     const bool fAllowToShowActionResize = isAllowedInMenuView(UIExtraDataMetaDefs::RuntimeMenuViewActionType_Resize);
-    const bool fAllowToShowActionMultiscreen = isAllowedInMenuView(UIExtraDataMetaDefs::RuntimeMenuViewActionType_Multiscreen);
-    const bool fAllowToShowActionScaleFactor = isAllowedInMenuView(UIExtraDataMetaDefs::RuntimeMenuViewActionType_ScaleFactor);
+    const bool fAllowToShowActionRemap = isAllowedInMenuView(UIExtraDataMetaDefs::RuntimeMenuViewActionType_Remap);
+    const bool fAllowToShowActionRescale = isAllowedInMenuView(UIExtraDataMetaDefs::RuntimeMenuViewActionType_Rescale);
 
     /* Clear contents: */
@@ -3255,6 +3255,6 @@
     }
 
-    /* Multiscreen actions: */
-    if (fAllowToShowActionMultiscreen && (m_cHostScreens > 1 || m_cGuestScreens > 1))
+    /* Remap actions: */
+    if (fAllowToShowActionRemap && (m_cHostScreens > 1 || m_cGuestScreens > 1))
     {
         updateMenuViewMultiscreen(pMenu);
@@ -3269,6 +3269,6 @@
     }
 
-    /* Scale factor actions: */
-    if (fAllowToShowActionScaleFactor)
+    /* Rescale actions: */
+    if (fAllowToShowActionRescale)
     {
         updateMenuViewScaleFactor(pMenu);
@@ -3720,10 +3720,9 @@
     }
 
     /* Do we have to show resize, multiscreen or scale factor actions? */
     const bool fAllowToShowActionResize = isAllowedInMenuView(UIExtraDataMetaDefs::RuntimeMenuViewActionType_Resize);
-    const bool fAllowToShowActionMultiscreen = isAllowedInMenuView(UIExtraDataMetaDefs::RuntimeMenuViewActionType_Multiscreen);
-    const bool fAllowToShowActionScaleFactor = isAllowedInMenuView(UIExtraDataMetaDefs::RuntimeMenuViewActionType_ScaleFactor);
-
-    if (fAllowToShowActionResize || fAllowToShowActionMultiscreen || fAllowToShowActionScaleFactor)
+    const bool fAllowToShowActionRemap = isAllowedInMenuView(UIExtraDataMetaDefs::RuntimeMenuViewActionType_Remap);
+    const bool fAllowToShowActionRescale = isAllowedInMenuView(UIExtraDataMetaDefs::RuntimeMenuViewActionType_Rescale);
+    if (fAllowToShowActionResize || fAllowToShowActionRemap || fAllowToShowActionRescale)
     {
         for (int iGuestScreenIndex = 0; iGuestScreenIndex < m_cGuestScreens; ++iGuestScreenIndex)
@@ -3765,8 +3764,8 @@
     }
 
     /* Do we have to show resize menu? */
     const bool fAllowToShowActionResize = isAllowedInMenuView(UIExtraDataMetaDefs::RuntimeMenuViewActionType_Resize);
-    const bool fAllowToShowActionScaleFactor = isAllowedInMenuView(UIExtraDataMetaDefs::RuntimeMenuViewActionType_ScaleFactor);
-    if (fAllowToShowActionResize || fAllowToShowActionScaleFactor)
+    const bool fAllowToShowActionRescale = isAllowedInMenuView(UIExtraDataMetaDefs::RuntimeMenuViewActionType_Rescale);
+    if (fAllowToShowActionResize || fAllowToShowActionRescale)
     {
         for (int iGuestScreenIndex = 0; iGuestScreenIndex < m_cGuestScreens; ++iGuestScreenIndex)
@@ -3780,4 +3779,5 @@
         }
     }
+
     /* Mark menu as valid: */
     m_invalidations.remove(UIActionIndexRT_M_ViewPopup);
@@ -3230,8 +3230,8 @@
     AssertPtrReturnVoid(pMenu);
 
-    /* Do we have to show resize, multiscreen or scale factor actions? */
+    /* Do we have to show resize, remap or rescale actions? */
     const bool fAllowToShowActionResize = isAllowedInMenuView(UIExtraDataMetaDefs::RuntimeMenuViewActionType_Resize);
@@ -3720,10 +3720,9 @@
     }
 
-    /* Do we have to show resize, multiscreen or scale factor actions? */
+    /* Do we have to show resize, remap or rescale actions? */
     const bool fAllowToShowActionResize = isAllowedInMenuView(UIExtraDataMetaDefs::RuntimeMenuViewActionType_Resize);
@@ -3765,8 +3764,8 @@
     }
 
-    /* Do we have to show resize menu? */
+    /* Do we have to show resize or rescale actions? */
     const bool fAllowToShowActionResize = isAllowedInMenuView(UIExtraDataMetaDefs::RuntimeMenuViewActionType_Resize);
Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/normal/UIMachineLogicNormal.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/normal/UIMachineLogicNormal.cpp	(revision 75357)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/normal/UIMachineLogicNormal.cpp	(revision 75358)
@@ -274,8 +274,8 @@
     UIMachineLogic::prepareActionGroups();
 
     /* Restrict 'Multiscreen' actions for 'View' menu: */
     actionPool()->toRuntime()->setRestrictionForMenuView(UIActionRestrictionLevel_Logic,
                                                          (UIExtraDataMetaDefs::RuntimeMenuViewActionType)
-                                                         (UIExtraDataMetaDefs::RuntimeMenuViewActionType_Multiscreen));
+                                                         (UIExtraDataMetaDefs::RuntimeMenuViewActionType_Remap));
 }
 
@@ -274,8 +274,8 @@
     UIMachineLogic::prepareActionGroups();
 
-    /* Restrict 'Multiscreen' actions for 'View' menu: */
+    /* Restrict 'Remap' actions for 'View' menu: */
     actionPool()->toRuntime()->setRestrictionForMenuView(UIActionRestrictionLevel_Logic,
                                                          (UIExtraDataMetaDefs::RuntimeMenuViewActionType)
Index: /trunk/src/VBox/Frontends/VirtualBox/src/runtime/scale/UIMachineLogicScale.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/runtime/scale/UIMachineLogicScale.cpp	(revision 75357)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/runtime/scale/UIMachineLogicScale.cpp	(revision 75358)
@@ -97,5 +97,5 @@
     UIMachineLogic::prepareActionGroups();
 
     /* Restrict 'Adjust Window', 'Guest Autoresize', 'Status Bar' and 'Resize' actions for 'View' menu: */
     actionPool()->toRuntime()->setRestrictionForMenuView(UIActionRestrictionLevel_Logic,
                                                          (UIExtraDataMetaDefs::RuntimeMenuViewActionType)
@@ -105,5 +105,5 @@
                                                           UIExtraDataMetaDefs::RuntimeMenuViewActionType_StatusBar |
                                                           UIExtraDataMetaDefs::RuntimeMenuViewActionType_Resize |
-                                                          UIExtraDataMetaDefs::RuntimeMenuViewActionType_ScaleFactor));
+                                                          UIExtraDataMetaDefs::RuntimeMenuViewActionType_Rescale));
 
     /* Take care of view-action toggle state: */
@@ -97,5 +97,5 @@
     UIMachineLogic::prepareActionGroups();
 
-    /* Restrict 'Adjust Window', 'Guest Autoresize', 'Status Bar' and 'Resize' actions for 'View' menu: */
+    /* Restrict 'Adjust Window', 'Guest Autoresize', 'Status Bar', 'Resize' and 'Rescale' actions for 'View' menu: */
     actionPool()->toRuntime()->setRestrictionForMenuView(UIActionRestrictionLevel_Logic,
                                                          (UIExtraDataMetaDefs::RuntimeMenuViewActionType)